@@ -1,6 +1,10 @@
 //! The solana-program-test provides a BanksClient-based test framework BPF programs
 #![allow(clippy::integer_arithmetic)]
 
+// Export types so test clients can limit their solana crate dependencies
+pub use solana_banks_client::BanksClient;
+// Export tokio for test clients
+pub use tokio;
 use {
     async_trait::async_trait,
     chrono_humanize::{Accuracy, HumanTime, Tense},
@@ -23,8 +27,7 @@ use {
         fee_calculator::{FeeCalculator, FeeRateGovernor},
         genesis_config::{ClusterType, GenesisConfig},
         hash::Hash,
-        instruction::Instruction,
-        instruction::InstructionError,
+        instruction::{Instruction, InstructionError},
         message::Message,
         native_token::sol_to_lamports,
         poh_config::PohConfig,
@@ -61,12 +64,6 @@ use {
     tokio::task::JoinHandle,
 };
 
-// Export types so test clients can limit their solana crate dependencies
-pub use solana_banks_client::BanksClient;
-
-// Export tokio for test clients
-pub use tokio;
-
 pub mod programs;
 
 #[macro_use]
